use strict;
use warnings;

use Test::Simple tests => 2;
use Test::NoWarnings;

use Test::Output;
use Test::Exception;
use Test::More ();
use Test::Most ();
use Test::MockObject;
use Test::Output;
use Test::Perl::Critic;
use Test::Pod;
use Test::Pod::Coverage;
use Test::Script;
use Test::WWW::Mechanize;


ok(1);

